import { IDatabaseExpression, IDatabaseService, IFilterExpressionBuilder, IGenericFilterQuery, IPaginatedResponse, IPaginationQuery, IQueryExecutor } from "@denis_bruns/foundation";
export declare abstract class BaseDatabaseService<TExpression extends IDatabaseExpression, TClient> implements IDatabaseService<any> {
    protected readonly tableName: string;
    protected readonly pkName: string;
    protected readonly expressionBuilder: IFilterExpressionBuilder<TExpression>;
    protected readonly queryExecutor: IQueryExecutor<TExpression, TClient>;
    protected constructor(tableName: string, pkName: string | undefined, expressionBuilder: IFilterExpressionBuilder<TExpression>, queryExecutor: IQueryExecutor<TExpression, TClient>);
    fetchWithFiltersAndPagination<T>(query: IGenericFilterQuery, client: TClient): Promise<IPaginatedResponse<T>>;
    protected abstract prepareQueryParameters(query: IGenericFilterQuery): Promise<{
        params: TExpression;
        limit: number;
        offset: number;
        page: number;
        pagination: IPaginationQuery;
    }>;
    protected abstract processResults<T>(items: any[], limit: number, offset: number, pagination: IPaginationQuery): T[];
    protected abstract handleError(error: any): void;
    protected calculatePaginationValues(pagination: IPaginationQuery): {
        limit: number;
        offset: number;
        page: number;
    };
}
